@@ -182,6 +182,10 @@ CLUTTER_AVAILABLE_IN_ALL GType clutter_script_error_get_type (void) G_GNUC_CONST
 CLUTTER_AVAILABLE_IN_ALL GType clutter_texture_error_get_type (void) G_GNUC_CONST;
 #define CLUTTER_TYPE_TEXTURE_ERROR (clutter_texture_error_get_type())
 
+/* enumerations from "./deprecated/clutter-shader.h" */
+CLUTTER_AVAILABLE_IN_ALL GType clutter_shader_error_get_type (void) G_GNUC_CONST;
+#define CLUTTER_TYPE_SHADER_ERROR (clutter_shader_error_get_type())
+
 /* enumerations from "./x11/clutter-x11.h" */
 CLUTTER_AVAILABLE_IN_ALL GType clutter_x11_filter_return_get_type (void) G_GNUC_CONST;
 #define CLUTTER_TYPE_X11_FILTER_RETURN (clutter_x11_filter_return_get_type())
