@@ -48,6 +48,8 @@ G_BEGIN_DECLS
  * of the specified portion at the same coordinates.
  *
  * Since: 0.2
+ *
+ * Deprecated: 1.22: Use the normalized #ClutterActor pivot point instead
  */
 typedef enum { /*< prefix=CLUTTER_GRAVITY >*/
   CLUTTER_GRAVITY_NONE       = 0,
@@ -86,6 +88,8 @@ typedef enum { /*< prefix=CLUTTER >*/
  * Direction of a rotation.
  *
  * Since: 0.4
+ *
+ * Deprecated: 1.22
  */
 typedef enum { /*< prefix=CLUTTER_ROTATE >*/
   CLUTTER_ROTATE_CW,
@@ -96,6 +100,8 @@ typedef enum { /*< prefix=CLUTTER_ROTATE >*/
  * ClutterRequestMode:
  * @CLUTTER_REQUEST_HEIGHT_FOR_WIDTH: Height for width requests
  * @CLUTTER_REQUEST_WIDTH_FOR_HEIGHT: Width for height requests
+ * @CLUTTER_REQUEST_CONTENT_SIZE: Use the preferred size of the
+ *   #ClutterContent, if it has any (available since 1.22)
  *
  * Specifies the type of requests for a #ClutterActor.
  *
@@ -103,7 +109,8 @@ typedef enum { /*< prefix=CLUTTER_ROTATE >*/
  */
 typedef enum { /*< prefix=CLUTTER_REQUEST >*/
   CLUTTER_REQUEST_HEIGHT_FOR_WIDTH,
-  CLUTTER_REQUEST_WIDTH_FOR_HEIGHT
+  CLUTTER_REQUEST_WIDTH_FOR_HEIGHT,
+  CLUTTER_REQUEST_CONTENT_SIZE
 } ClutterRequestMode;
 
 /**
@@ -274,6 +281,8 @@ typedef enum {
  * clutter_set_font_flags().
  *
  * Since: 1.0
+ *
+ * Deprecated: 1.22: Use #cairo_font_options_t instead
  */
 typedef enum { /*< prefix=CLUTTER_FONT >*/
   CLUTTER_FONT_MIPMAPPING = (1 << 0),
@@ -477,6 +486,8 @@ typedef enum { /*< prefix=CLUTTER_ALIGN >*/
  * The mode of interpolation between key frames
  *
  * Since: 1.2
+ *
+ * Deprecated: 1.22
  */
 typedef enum {
   CLUTTER_INTERPOLATION_LINEAR,
@@ -734,7 +745,7 @@ typedef enum { /*< flags prefix=CLUTTER_EVENT >*/
  * @CLUTTER_BUTTON_PRESS: Pointer button press event
  * @CLUTTER_BUTTON_RELEASE: Pointer button release event
  * @CLUTTER_SCROLL: Pointer scroll event
- * @CLUTTER_STAGE_STATE: Stage stage change event
+ * @CLUTTER_STAGE_STATE: Stage state change event
  * @CLUTTER_DESTROY_NOTIFY: Destroy notification event
  * @CLUTTER_CLIENT_MESSAGE: Client message event
  * @CLUTTER_DELETE: Stage delete event
@@ -829,7 +840,7 @@ typedef enum {
  * @CLUTTER_FEATURE_SWAP_EVENTS: Set if the GLX_INTEL_swap_event is supported.
  *
  * Runtime flags indicating specific features available via Clutter window
- * sysytem and graphics backend.
+ * system and graphics backend.
  *
  * Since: 0.4
  */
@@ -1033,6 +1044,8 @@ typedef enum { /*< prefix=CLUTTER_PAN >*/
  * The alignment policies available on each axis of the #ClutterTableLayout
  *
  * Since: 1.4
+ *
+ * Deprecated: 1.22: Use the alignment properties of #ClutterActor
  */
 typedef enum {
   CLUTTER_TABLE_ALIGNMENT_START,
@@ -1043,22 +1056,23 @@ typedef enum {
 /**
  * ClutterTextureFlags:
  * @CLUTTER_TEXTURE_NONE: No flags
- * @CLUTTER_TEXTURE_RGB_FLAG_BGR: FIXME
- * @CLUTTER_TEXTURE_RGB_FLAG_PREMULT: FIXME
- * @CLUTTER_TEXTURE_YUV_FLAG_YUV2: FIXME
+ * @CLUTTER_TEXTURE_RGB_FLAG_BGR: Unused flag
+ * @CLUTTER_TEXTURE_RGB_FLAG_PREMULT: Unused flag
+ * @CLUTTER_TEXTURE_YUV_FLAG_YUV2: Unused flag
  *
  * Flags for clutter_texture_set_from_rgb_data() and
  * clutter_texture_set_from_yuv_data().
  *
  * Since: 0.4
+ *
+ * Deprecated: 1.22: The #ClutterTexture class was the only user of
+ *   this API
  */
 typedef enum { /*< prefix=CLUTTER_TEXTURE >*/
   CLUTTER_TEXTURE_NONE             = 0,
   CLUTTER_TEXTURE_RGB_FLAG_BGR     = 1 << 1,
   CLUTTER_TEXTURE_RGB_FLAG_PREMULT = 1 << 2, /* FIXME: not handled */
   CLUTTER_TEXTURE_YUV_FLAG_YUV2    = 1 << 3
-
-  /* FIXME: add compressed types ? */
 } ClutterTextureFlags;
 
 /**
@@ -1073,6 +1087,10 @@ typedef enum { /*< prefix=CLUTTER_TEXTURE >*/
  * Enumaration controlling the texture quality.
  *
  * Since: 0.8
+ *
+ * Deprecated: 1.22: The #ClutterTexture class was the only used ot
+ *   this API; use #ClutterImage and clutter_actor_set_content_scaling_filters()
+ *   instead.
  */
 typedef enum { /*< prefix=CLUTTER_TEXTURE_QUALITY >*/
   CLUTTER_TEXTURE_QUALITY_LOW,
@@ -1357,6 +1375,29 @@ typedef enum { /*< prefix=CLUTTER_ZOOM >*/
   CLUTTER_ZOOM_BOTH
 } ClutterZoomAxis;
 
+/**
+ * ClutterGestureTriggerEdge:
+ * @CLUTTER_GESTURE_TRIGGER_EDGE_NONE: Tell #ClutterGestureAction that
+ * the gesture must begin immediately and there's no drag limit that
+ * will cause its cancellation;
+ * @CLUTTER_GESTURE_TRIGGER_EDGE_AFTER: Tell #ClutterGestureAction that
+ * it needs to wait until the drag threshold has been exceeded before
+ * considering that the gesture has begun;
+ * @CLUTTER_GESTURE_TRIGGER_EDGE_BEFORE: Tell #ClutterGestureAction that
+ * the gesture must begin immediately and that it must be cancelled
+ * once the drag exceed the configured threshold.
+ *
+ * Enum passed to the clutter_gesture_action_set_threshold_trigger_edge()
+ * function.
+ *
+ * Since: 1.18
+ */
+typedef enum {
+  CLUTTER_GESTURE_TRIGGER_EDGE_NONE  = 0,
+  CLUTTER_GESTURE_TRIGGER_EDGE_AFTER,
+  CLUTTER_GESTURE_TRIGGER_EDGE_BEFORE
+} ClutterGestureTriggerEdge;
+
 G_END_DECLS
 
 #endif /* __CLUTTER_ENUMS_H__ */
